==> dde-launcher_4.4.5.5.orig.tar.xz: dde-launcher-4.4.5.5/translations/dde-launcher_bg.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="bg" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Търсенето е без резултат</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Наистина ли ще деинсталирате %1?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отказ</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Потвърждение</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Премахнете от работния плот</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Разкачане</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Деинсталиране</translation>
    </message>
    <message>
        <source>Open by proxy</source>
        <translation>Отваряне чрез прокси</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Забрана за мащабиране на екрана</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Отваряне</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Изпрати на работният плот</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Изпрати на дока</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Премахване от стартиращи</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Добавяне към стартиращи</translation>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Всички програми</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Интернет</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Чат</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Музика</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Видео</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Графика</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Игра</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Офис</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Четене</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Разработка</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Система</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Други</translation>
    </message>
</context>
<context>
    <name>MiniFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Наистина ли ще деинсталирате %1?</translation>
    </message>
    <message>
        <source>All dependencies will be removed together</source>
        <translation>Всички зависимости ще бъдат премахнати заедно</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отказ</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Потвърждение</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Компютър</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Документи</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Видеа</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Музика</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Картини</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Свалени</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>3аключвам</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Изход</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Рестарт</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Приспиване</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Изключване</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Върни</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Компютър</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Музика</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Изключване</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>3аключвам</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Изход</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Рестарт</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Приспиване</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Върни</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Документи</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Видеа</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Картини</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Свалени</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Компютър</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Музика</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Свалени</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ръчно</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Изключване</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Видеа</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Картини</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Документи</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>Всички файлове</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Търсене</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Наистина ли ще деинсталирате %1?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отказ</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Потвърждение</translation>
    </message>
</context>
</TS>

==> dde-launcher_4.6.13.orig.tar.xz: dde-launcher-4.6.13/translations/dde-launcher_bg.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="bg" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Търсенето е без резултат</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Интернет</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Чат</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Музика</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Видео</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Графика</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Офис</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Четене</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Разработка</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Система</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Игри</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Други</translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Отказ</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Потвърждение</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Премахнете от работния плот</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Премахване от дока</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Деинсталиране</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Забрана за мащабиране на екрана</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Отваряне</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Изпрати на работния плот</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Изпрати на дока</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Премахване от стартиращи</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Добавяне към стартиращи</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Всички програми</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Интернет</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Чат</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Музика</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Видео</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Графика</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Игра</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Офис</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Четене</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Разработка</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Система</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Други</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Компютър</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Документи</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Видеа</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Музика</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Картини</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Свалени</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>3аключване</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Изход</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Рестартиране</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Приспиване</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Изключване</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Връщане</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Компютър</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Музика</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Изключване</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>3аключване</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Излизане</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Рестартиране</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Приспиване</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Връщане</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Документи</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Видеа</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Картини</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Свалени</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Компютър</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Музика</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Свалени</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ръчно</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Видеа</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Картини</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Документи</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>Захранване</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>Всички категории</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Връщане</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Търсене</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Отказ</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Потвърждение</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
